# Another Example Title

## This is an H2

{image alt="This is alt text" file-path="totally-legit-image.png"}

This is a sentence.

{glossary-link term="chomsky-hierarchy" reference-text="Formal languages"}Chomsky Hierarchy{glossary-link end}
